EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_GetItemFromPath',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'AssetItems(1),AssetItemMetadata',
    /* OutputPropertyNames_Csv */ 'CanonicalAssetPath_Text,Inherited_CacheConfiguration_XML',
    /* Description_Text        */ 'Uses Assets_FindFromPath to find an item, then returns it along with the properly-cased path, inherited cache configuration, and user-defined metadata.',
	/* Remarks_Text            */ 'See Assets_FindFromPath: path must use forward slash (/) and not have any leading or trailing slashes. Paths are case-sensitive unless AllowCaseInsensitiveMatch_Indicator is Y.'
GO

IF OBJECT_ID('[Assets_GetItemFromPath]') IS NOT NULL DROP PROCEDURE [Assets_GetItemFromPath]
GO


SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_GetItemFromPath]
(
	@Feed_Id INT,
	@AssetPath_Text NVARCHAR(MAX),
	@IncludeDeleted_Indicator YNINDICATOR,
	@AllowCaseInsensitiveMatch_Indicator YNINDICATOR,

	@CanonicalAssetPath_Text NVARCHAR(MAX) = NULL OUT,
	@Inherited_CacheConfiguration_XML XML = NULL OUT
)
AS
BEGIN

	DECLARE @AssetItem_Id INT
	EXEC [Assets_FindFromPath] 
		@Feed_Id, @AssetPath_Text, @IncludeDeleted_Indicator, @AllowCaseInsensitiveMatch_Indicator,
		@AssetItem_Id OUT, @CanonicalAssetPath_Text OUT, @Inherited_CacheConfiguration_XML OUT

	
	SELECT *
	  FROM [AssetItems]
	 WHERE [AssetItem_Id] = @AssetItem_Id

	SELECT *
	  FROM [AssetItemMetadata]
	 WHERE [AssetItem_Id] = @AssetItem_Id

END
GO

GRANT EXECUTE ON [Assets_GetItemFromPath] TO [ProGetUser_Role]