EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedPackageAccessRules_CreateOrUpdateRule',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new feed access rule or updates an existing one.'
GO

IF OBJECT_ID('[FeedPackageAccessRules_CreateOrUpdateRule]') IS NOT NULL DROP PROCEDURE [FeedPackageAccessRules_CreateOrUpdateRule]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [FeedPackageAccessRules_CreateOrUpdateRule]
(
	@Feed_Id INT,
	@PackageAccessRule_Name NVARCHAR(50),
	@PackageAccessRule_Configuration XML,
	@Sequence_Number INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [FeedPackageAccessRules] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Sequence_Number] = @Sequence_Number)
	BEGIN

		UPDATE [FeedPackageAccessRules]
		   SET [PackageAccessRule_Name] = @PackageAccessRule_Name,
			   [PackageAccessRule_Configuration] = @PackageAccessRule_Configuration
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Sequence_Number] = @Sequence_Number

	END
	ELSE
	BEGIN

		SET @Sequence_Number = (SELECT COALESCE(MAX([Sequence_Number]), 0) + 1
		                          FROM [FeedPackageAccessRules]
		                          WITH (UPDLOCK)
		                         WHERE [Feed_Id] = @Feed_Id)

		INSERT INTO [FeedPackageAccessRules]
		(
			[Feed_Id],
			[Sequence_Number],
			[PackageAccessRule_Name],
			[PackageAccessRule_Configuration]
		)
		VALUES
		(
			@Feed_Id,
			@Sequence_Number,
			@PackageAccessRule_Name,
			@PackageAccessRule_Configuration
		)

	END

	EXEC [Events_RaiseEvent] 'FEDMDF', @Feed_Id, 'PackageAccessRule_Name', @PackageAccessRule_Name
	
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [FeedPackageAccessRules_CreateOrUpdateRule] TO [ProGetUser_Role]
GO
	   

