EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedReplications_CreateOrUpdateReplication',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'FeedReplication_Id',
    /* Description_Text        */ 'Creates a new feed replication or updates an existing one.'
GO

IF OBJECT_ID('[FeedReplications_CreateOrUpdateReplication]') IS NOT NULL DROP PROCEDURE [FeedReplications_CreateOrUpdateReplication]
GO


SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [FeedReplications_CreateOrUpdateReplication]
(
	@FeedReplication_Configuration XML,
	@Draft_Indicator YNINDICATOR = NULL,
	@FeedReplication_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @FeedReplication_Id IS NULL
	BEGIN

		INSERT INTO [FeedReplications]
		(
			[Draft_Indicator],
			[FeedReplication_Configuration],
			[ModifiedOn_Date],
			[ModifiedBy_User]
		)
		VALUES
		(
			COALESCE(@Draft_Indicator, 'N'),
			@FeedReplication_Configuration,
			GETUTCDATE(),
			COALESCE(dbo.Session_GetUserName(), 'SYSTEM')
		)

		SET @FeedReplication_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [FeedReplications]
		   SET [Draft_Indicator] = COALESCE(@Draft_Indicator, [Draft_Indicator]),
		       [FeedReplication_Configuration] = COALESCE(@FeedReplication_Configuration, [FeedReplication_Configuration]),
			   [ModifiedOn_Date] = GETUTCDATE(),
			   [ModifiedBy_User] = COALESCE(dbo.Session_GetUserName(), 'SYSTEM')
		 WHERE [FeedReplication_Id] = @FeedReplication_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO



GRANT EXECUTE ON [FeedReplications_CreateOrUpdateReplication] TO [ProGetUser_Role]
GO
	   

