EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'LicenseRules_CreateOrUpdateLicenseRule',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'LicenseRule_Id',
    /* Description_Text        */ 'Creates or edits a license rule.'
GO

IF OBJECT_ID('[LicenseRules_CreateOrUpdateLicenseRule]') IS NOT NULL DROP PROCEDURE [LicenseRules_CreateOrUpdateLicenseRule]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LicenseRules_CreateOrUpdateLicenseRule]
(
	@Feed_Id INT,
	@License_Id INT,
	@Allow_Indicator YNINDICATOR,
	@LicenseRule_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

	DECLARE @Operation_Name NVARCHAR(50)

	IF @LicenseRule_Id IS NOT NULL
	BEGIN
		UPDATE [LicenseRules]
		   SET [Feed_Id] = @Feed_Id,
		       [License_Id] = @License_Id,
			   [Allow_Indicator] = @Allow_Indicator
		 WHERE [LicenseRule_Id] = @LicenseRule_Id

		 SET @Operation_Name = N'UPDATE'
	END
	ELSE
	BEGIN
		INSERT INTO [LicenseRules]
		(
			[Feed_Id],
			[License_Id],
			[Allow_Indicator]
		)
		VALUES
		(
			@Feed_Id,
			@License_Id,
			@Allow_Indicator
		)

		SET @LicenseRule_Id = SCOPE_IDENTITY()
		SET @Operation_Name = N'CREATE'
	END

	DECLARE @External_Id VARCHAR(50)
	SET @External_Id = (SELECT [External_Id] FROM [Licenses] WHERE [License_Id] = @License_Id)

	EXEC [Events_RaiseEvent] 'LICRUL', @Feed_Id, N'LicenseRule_Id', @LicenseRule_Id, N'External_Id', @External_Id, N'Allow_Indicator', @Allow_Indicator, 'Operation_Name', @Operation_Name

END
GO

GRANT EXECUTE ON [LicenseRules_CreateOrUpdateLicenseRule] TO [ProGetUser_Role]
GO
